@@ -7,7 +7,7 @@ class ConfigTest < Net::IMAP::TestCase
   Config = Net::IMAP::Config
   THIS_VERSION   = Net::IMAP::VERSION.to_f
   NEXT_VERSION   = THIS_VERSION + 0.1
-  FUTURE_VERSION = THIS_VERSION + 0.2
+  FUTURE_VERSION = 1.0
 
   setup do
     Config.global.reset
@@ -72,6 +72,7 @@ class ConfigTest < Net::IMAP::TestCase
   test ".default" do
     default = Config.default
     assert default.equal?(Config.default)
+    assert_nil default.parent
     assert default.is_a?(Config)
     assert default.frozen?
     refute default.debug?
@@ -184,8 +185,7 @@ class ConfigTest < Net::IMAP::TestCase
     assert_raise(RangeError) do Config[0.01] end
     assert_raise(RangeError) do Config[0.11] end
     assert_raise(RangeError) do Config[0.111] end
-    assert_raise(RangeError) do Config[0.9] end
-    assert_raise(RangeError) do Config[1] end
+    assert_raise(RangeError) do Config[1.1] end
   end
 
   test ".[] key errors" do
@@ -308,21 +308,41 @@ class ConfigTest < Net::IMAP::TestCase
     assert_equal 1, copy.open_timeout
   end
 
-  test "#inherited? and #reset(attr)" do
+  test "#inherited? and #reset" do
     base = Config.new debug: false, open_timeout: 99, idle_response_timeout: 15
     child = base.new debug: true, open_timeout: 15, idle_response_timeout: 10
+    refute child.inherited?
     refute child.inherited?(:idle_response_timeout)
+    refute child.inherited?(:idle_response_timeout, :open_timeout)
+    refute child.inherited?(:sasl_ir, :open_timeout)
+    assert child.inherited?(:sasl_ir, :max_response_size)
+    assert child.inherited?(:sasl_ir)
+
     assert_equal 10, child.reset(:idle_response_timeout)
-    assert child.inherited?(:idle_response_timeout)
     assert_equal 15, child.idle_response_timeout
+    refute child.inherited?
+    assert child.inherited?(:idle_response_timeout)
+    refute child.inherited?(:idle_response_timeout, :open_timeout)
+    refute child.inherited?(:sasl_ir, :open_timeout)
+    assert child.inherited?(:sasl_ir, :max_response_size)
+    assert child.inherited?(:sasl_ir)
     refute child.inherited?(:open_timeout)
     refute child.inherited?(:debug)
+
     child.debug = false
+    refute child.inherited?
     refute child.inherited?(:debug)
+
     assert_equal false, child.reset(:debug)
+    refute child.inherited?
     assert child.inherited?(:debug)
     assert_equal false, child.debug
+
     assert_equal nil, child.reset(:debug)
+
+    assert_same child, child.reset
+    assert child.inherited?
+    assert child.inherited?(:debug, :idle_response_timeout, :open_timeout)
   end
 
   test "#reset all attributes" do
@@ -440,4 +460,77 @@ class ConfigTest < Net::IMAP::TestCase
     assert_raise(TypeError) do config.max_response_size = :invalid  end
   end
 
+  def config_id(config)
+    Kernel.instance_method(:to_s).bind_call(config).match(/0x(\h*)>/)[1]
+  end
+
+  test "#inspect" do
+    assert_equal(
+      "#<#{Config}.global inherits from #{Config}.default>",
+      Config.global.inspect
+    )
+
+    Config.global.debug = true
+    assert_equal(
+      "#<#{Config}.global debug=true inherits from #{Config}.default>",
+      Config.global.inspect
+    )
+
+    config = Config.global.new(sasl_ir: true)
+    id = config_id(config)
+    assert_equal(
+      "#<#{Config}:0x#{id} sasl_ir=true " \
+      "inherits from #{Config}.global debug=true " \
+      "inherits from #{Config}.default>",
+      config.inspect
+    )
+
+    Config.global.reset(:debug)
+    nested = Config[0.4].new(sasl_ir: true).new(open_timeout: 60)
+    assert_equal(
+      "#<#{Config}:0x#{config_id(nested)} open_timeout=60 " \
+      "inherits from #{Config}:0x#{config_id(nested.parent)} sasl_ir=true " \
+      "inherits from #{Config}[0.4] " \
+      "inherits from #{Config}.global " \
+      "inherits from #{Config}.default>",
+      nested.inspect
+    )
+
+    config_attrs = Config::AttrAccessors.struct.members
+      .map { / #{_1}=.+/.source }.join
+    assert_match(
+      /#<#{Config}.default#{config_attrs}>/,
+      Config.default.inspect
+    )
+  end
+
+  test "#pretty_print" do
+    default_attrs = Config.global.to_h.map { "%s=%p" % _1 }
+    width = 80
+    output = String.new
+    PP.pp Config.global, output, width
+    assert_equal(<<~PP, output)
+      #<#{Config}.global
+        inherits from #{Config}.default
+          #{default_attrs.join("\n    ")}>
+    PP
+
+    Config.global.debug = true
+    config = Config[0.5].new(enforce_logindisabled: :when_capabilities_cached)
+    default_attrs = Config[0.5].to_h.except(:debug, :enforce_logindisabled)
+      .map { "%s=%p" % _1 }
+
+    output = String.new
+    PP.pp config, output, width
+    assert_equal(<<~PP, output)
+      #<#{Config}:0x#{config_id(config)}
+        enforce_logindisabled=:when_capabilities_cached
+        inherits from #{Config}[0.5]
+          #{default_attrs.join("\n    ")}
+          inherits from #{Config}.global
+            debug=true
+            inherits from #{Config}.default
+              (overridden)>
+    PP
+  end
 end
