@@ -89,6 +89,9 @@ class IMAPSequenceSetTest < Net::IMAP::TestCase
       assert_equal intersection, lhs - (lhs - rhs)
       assert_equal intersection, lhs - (lhs ^ rhs)
       assert_equal intersection, lhs ^ (lhs - rhs)
+      mutable = lhs.dup
+      assert_equal intersection, mutable.intersect!(rhs)
+      assert_equal intersection, mutable
     end
   end
 
@@ -118,6 +121,9 @@ class IMAPSequenceSetTest < Net::IMAP::TestCase
       assert_equal xor, (lhs | rhs) - (lhs & rhs)
       assert_equal xor, (lhs ^ mid) ^ (mid ^ rhs)
       assert_equal xor, ~lhs ^ ~rhs
+      mutable = lhs.dup
+      assert_equal xor, mutable.xor!(rhs)
+      assert_equal xor, mutable
     end
   end
 
@@ -168,6 +174,8 @@ class IMAPSequenceSetTest < Net::IMAP::TestCase
   data "#merge",       ->{ _1.merge     1 }
   data "#subtract",    ->{ _1.subtract  1 }
   data "#limit!",      ->{ _1.limit! max: 10 }
+  data "#intersect!",  ->{ _1.intersect! SequenceSet[1..100] }
+  data "#xor!",        ->{ _1.xor!       SequenceSet[9..98]  }
   data "#complement!", :complement!
   data "#normalize!",  :normalize!
   test "frozen error message" do |modification|
@@ -433,6 +441,7 @@ class IMAPSequenceSetTest < Net::IMAP::TestCase
   test "#[start, length]" do
     assert_equal SequenceSet[10..99], SequenceSet.full[9, 90]
     assert_equal 90, SequenceSet.full[9, 90].count
+    assert_equal 90, SequenceSet.full[9, 90].cardinality
     assert_equal SequenceSet[1000..1099],
                  SequenceSet[1..100, 1000..1111][100, 100]
     assert_equal SequenceSet[11, 21, 31, 41],
@@ -653,15 +662,27 @@ class IMAPSequenceSetTest < Net::IMAP::TestCase
     assert_equal "1,5",     SequenceSet.new("1").append("5").string
     assert_equal "*,1",     SequenceSet.new("*").append(1).string
     assert_equal "1:6,4:9", SequenceSet.new("1:6").append("4:9").string
-    assert_equal "1:4,5:*", SequenceSet.new("1:4").append(5..).string
     assert_equal "5:*,1:4", SequenceSet.new("5:*").append(1..4).string
+    # also works when previous string was not normal
+    assert_equal "3:1,8:9", SequenceSet.new("3:1").append("9:8").string
+    # coalesces adjacent entries (when previously normalized)
+    assert_equal "1:9",     SequenceSet.new("1:3").append("4:9").string
+    assert_equal "1:9",     SequenceSet.new("1:3").append("9:4").string
+    assert_equal "1:*",     SequenceSet.new("1:4").append(5..).string
+    # coalesces adjacent entries (when _not_ previously normalized)
+    assert_equal "1:9",     SequenceSet.new("3:1").append("4:9").string
+    assert_equal "4,1:*",   SequenceSet.new("4,1").append(2..).string
+    # assert_equal "3:1,4:9", SequenceSet.new("3:1").append("4:9").string
+    # a non-normal appended string will be normalized
+    assert_equal "1:6,4:9", SequenceSet.new("1:6").append("9:4").string
+    assert_equal "1:6,999", SequenceSet.new("1:6").append("999:999").string
     # also works from empty
     assert_equal "5,1",     SequenceSet.new.append(5).append(1).string
     # also works when *previously* input was non-strings
     assert_equal "*,1",     SequenceSet.new(:*).append(1).string
     assert_equal "1,5",     SequenceSet.new(1).append("5").string
     assert_equal "1:6,4:9", SequenceSet.new(1..6).append(4..9).string
-    assert_equal "1:4,5:*", SequenceSet.new(1..4).append(5..).string
+    assert_equal "1:*",     SequenceSet.new(1..4).append(5..).string
     assert_equal "5:*,1:4", SequenceSet.new(5..).append(1..4).string
   end
 
@@ -1045,6 +1066,7 @@ class IMAPSequenceSetTest < Net::IMAP::TestCase
     to_s:       "4294967000:*",
     normalize:  "4294967000:*",
     count:      2**32 - 4_294_967_000,
+    cardinality: 2**32 - 4_294_967_000 + 1,
     complement: "1:4294966999",
   }, keep: true
 
@@ -1123,6 +1145,8 @@ class IMAPSequenceSetTest < Net::IMAP::TestCase
     normalize:  "2:*",
     count:      2**32 - 2,
     count_dups: 2**32 - 2,
+    size:       2**33 - 2,
+    cardinality: 2**32 - 1,
     complement: "1",
   }, keep: true
 
@@ -1162,6 +1186,36 @@ class IMAPSequenceSetTest < Net::IMAP::TestCase
     complement: "6:8,12:98,100:#{2**32 - 1}",
   }, keep: true
 
+  data "UINT32_MAX,*", {
+    input:      "#{2**32-1},*",
+    elements:   [2**32 - 1..],
+    entries:    [2**32 - 1, :*],
+    ranges:     [2**32 - 1..],
+    numbers:    RangeError,
+    to_s:       "#{2**32 - 1},*",
+    normalize:  "#{2**32 - 1}:*",
+    count:      1,
+    cardinality: 2,
+    count_dups: 1,
+    size:       2,
+    complement: "1:#{2**32 - 2}",
+  }, keep: true
+
+  data "UINT32_MAX:*", {
+    input:      "#{2**32-1}:*",
+    elements:   [2**32 - 1..],
+    entries:    [2**32 - 1..],
+    ranges:     [2**32 - 1..],
+    numbers:    RangeError,
+    to_s:       "#{2**32 - 1}:*",
+    normalize:  "#{2**32 - 1}:*",
+    count:      1,
+    cardinality: 2,
+    count_dups: 0,
+    size:       2,
+    complement: "1:#{2**32 - 2}",
+  }, keep: true
+
   data "empty", {
     input:      nil,
     elements:   [],
@@ -1279,6 +1333,15 @@ class IMAPSequenceSetTest < Net::IMAP::TestCase
     assert_equal data[:normalize], set.normalized_string
   end
 
+  test "#normalized?" do |data|
+    set = SequenceSet.new(data[:input])
+    eql = set.normalized_string == set.string
+    msg = "expect string=%p and normalized_string=%p %s normal" % [
+      set.string, set.normalized_string, eql ? "to be" : "not to be"
+    ]
+    assert set.normalized? == eql, msg
+  end
+
   test "#normalize" do |data|
     set = SequenceSet.new(data[:input])
     assert_equal data[:normalize], set.normalize.string
@@ -1300,6 +1363,20 @@ class IMAPSequenceSetTest < Net::IMAP::TestCase
     assert_equal data[:count], SequenceSet.new(data[:input]).count
   end
 
+  test "#size" do |data|
+    expected = data[:size] || begin
+      dups = data[:count_dups]  || 0
+      card = data[:cardinality] || data[:count]
+      card + dups
+    end
+    assert_equal expected, SequenceSet.new(data[:input]).size
+  end
+
+  test "#cardinality" do |data|
+    expected = data[:cardinality] || data[:count]
+    assert_equal expected, SequenceSet.new(data[:input]).cardinality
+  end
+
   test "#count_with_duplicates" do |data|
     dups = data[:count_dups] || 0
     count = data[:count] + dups
